from django.shortcuts import render
from django.http import HttpResponseRedirect
import subprocess
import os

def home(request):
    return render(request, 'home.html')

def upload_form(request):
    return render(request, 'upload_form.html')

def run():
    # Start the Django development server
    subprocess.run(['python3', 'manage.py', 'runserver'])



from setuptools import setup, find_packages
from setuptools.command.install import install
import subprocess

class PostInstallCommand(install):
    def run(self):
        install.run(self)
        subprocess.call(['cenas-post-install'])

setup(
    name='cenas',
    version='1.1.5',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'django',
        # Add any other dependencies here
    ],
    cmdclass={
        'install': PostInstallCommand,
    },
    entry_points={
        'console_scripts': [
            'cenas=cenas.views:run',
            'cenas-post-install=cenas.scripts.post_install:run_post_install',
        ],
    },
)
